==> ckeditor5_youtube-1.0.0.tar.gz: ckeditor5_youtube/README.md <==
# CKEditor 5 YouTube Embed Module

## Introduction

The CKEditor 5 YouTube Embed module enhances the CKEditor 5 text editor in Drupal by adding a YouTube embed functionality. This module allows content creators to easily embed YouTube videos into their content using a user-friendly interface.

## Features

- Adds a YouTube embed button to the CKEditor 5 toolbar
- Provides a dialog for entering YouTube video URLs
- Customizable video display options

## Requirements

- Drupal 9.x, 10.x or 11.x
- CKEditor 5 module enabled

## Installation

1. Download and place the module in your `modules/contrib` directory.
2. Enable the module through the Drupal admin interface or using Drush:
   ```
   drush en ckeditor5_youtube
   ```

## Configuration

1. Go to Administration > Configuration > Content Authoring > Text formats and editors
2. Edit the desired text format that uses CKEditor 5
3. In the toolbar configuration, add the YouTube embed button to your active toolbar
4. Save the configuration

## Usage

1. When editing content, click on the YouTube embed button in the CKEditor toolbar
2. Enter the YouTube video URL in the dialog that appears
3. Adjust any available options for the video display
4. Click "✓" to insert the video into your content

## Contributing

Contributions to the CKEditor 5 YouTube Embed module are welcome. Please follow [Drupal coding standards](https://www.drupal.org/docs/develop/standards) when submitting patches or pull requests.

## License

This module is licensed under the GNU General Public License v2.0 or later.

## Maintainers

- [Abderrahim GHAZALI] - https://www.drupal.org/u/abdei

For bug reports, feature requests, and support, please use the [issue queue on Drupal.org](https://www.drupal.org/project/issues/ckeditor5_youtube).

==> ckeditor5_youtube-1.0.1.tar.gz: ckeditor5_youtube/README.md <==
# CKEditor 5 YouTube Embed Module

## Introduction

The CKEditor 5 YouTube Embed module enhances the CKEditor 5 text editor in
Drupal by adding a YouTube embed functionality.
This module allows content creators to easily embed YouTube videos
into their content using a user-friendly interface.

## Features

- Adds a YouTube embed button to the CKEditor 5 toolbar
- Provides a dialog for entering YouTube video URLs
- Customizable video display options

## Requirements

- Drupal 9.x, 10.x or 11.x
- CKEditor 5 module enabled

## Installation

1. Download and place the module in your `modules/contrib` directory.
2. Enable the module through the Drupal admin interface or using Drush:
   ```
   drush en ckeditor5_youtube
   ```

## Configuration

1. Go to Administration > Configuration > Content Authoring >
Text formats and editors
2. Edit the desired text format that uses CKEditor 5
3. In the toolbar configuration, add the YouTube embed button to
your active toolbar
4. Save the configuration

## Usage

1. When editing content, click on the YouTube embed button in the CKEditor
toolbar
2. Enter the YouTube video URL in the dialog that appears
3. Adjust any available options for the video display
4. Click "✓" to insert the video into your content

## Contributing

Contributions to the CKEditor 5 YouTube Embed module are welcome.
Please follow [Drupal coding standards](https://www.drupal.org/docs/develop/standards) when submitting patches or pull requests.

## License

This module is licensed under the GNU General Public License v2.0 or later.

## Maintainers

- [Abderrahim GHAZALI] - https://www.drupal.org/u/abdei

For bug reports, feature requests, and support, please use the [issue queue on Drupal.org](https://www.drupal.org/project/issues/ckeditor5_youtube).
